import { __decorate } from 'tslib';
import { EventEmitter, ViewChild, Output, Input, Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

let StimulsoftDesignerComponent = class StimulsoftDesignerComponent {
    constructor() {
        /**
         * Occurs when designer loaded
         */
        this.designerLoaded = new EventEmitter();
        this.id = 'aDesigner' + (Math.random() * 10000000).toString();
        this.loaded = false;
    }
    ngOnInit() {
        this.addScript();
    }
    ngOnChanges(changes) {
        this.addScript();
    }
    addScript() {
        if (this.chartScripts) {
            this.head.removeChild(this.chartScripts);
        }
        this.chartScripts = document.createElement('Script');
        this.chartScripts.setAttribute('type', 'text/javascript');
        this.chartScripts.src = this.requestUrl;
        this.chartScripts.addEventListener('load', () => {
            if (!this.loaded) {
                try {
                    const options = new Stimulsoft.Designer.StiDesignerOptions();
                    this.loaded = true;
                    setTimeout(() => {
                        this.designerLoaded.next();
                    });
                    this.showDesigner();
                }
                catch (_a) { }
            }
        });
        this.head.appendChild(this.chartScripts);
    }
    showDesigner() {
        const options = new Stimulsoft.Designer.StiDesignerOptions();
        if (this.width) {
            options.width = this.width;
        }
        if (this.height) {
            options.height = this.height;
        }
        this.designer = new Stimulsoft.Designer.StiDesigner(options, 'StiDesigner', false);
        this.designer.renderHtml(this.designerEl.nativeElement);
    }
    get head() {
        return document.getElementsByTagName('head')[0];
    }
};
__decorate([
    ViewChild('designer')
], StimulsoftDesignerComponent.prototype, "designerEl", void 0);
__decorate([
    Output()
], StimulsoftDesignerComponent.prototype, "designerLoaded", void 0);
__decorate([
    Input()
], StimulsoftDesignerComponent.prototype, "requestUrl", void 0);
__decorate([
    Input()
], StimulsoftDesignerComponent.prototype, "width", void 0);
__decorate([
    Input()
], StimulsoftDesignerComponent.prototype, "height", void 0);
StimulsoftDesignerComponent = __decorate([
    Component({
        selector: 'stimulsoft-designer-angular',
        template: `
    <div #designer [attr.id]="id">
      <ng-content></ng-content>
    </div>
  `
    })
], StimulsoftDesignerComponent);

let StimulsoftDesignerModule = class StimulsoftDesignerModule {
};
StimulsoftDesignerModule = __decorate([
    NgModule({
        declarations: [StimulsoftDesignerComponent],
        imports: [
            CommonModule
        ],
        exports: [StimulsoftDesignerComponent]
    })
], StimulsoftDesignerModule);

/*
 * Public API Surface of stimulsoft-designer-angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { StimulsoftDesignerComponent, StimulsoftDesignerModule };
//# sourceMappingURL=stimulsoft-designer-angular.js.map
